package com.ningdatech.pmapi.scheduler.task;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.date.StopWatch;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.ningdatech.basic.exception.BizException;
import com.ningdatech.pmapi.scheduler.contants.TaskContant;
import com.ningdatech.pmapi.sys.contants.RegionContant;
import com.ningdatech.pmapi.sys.entity.Region;
import com.ningdatech.pmapi.sys.service.IRegionService;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import java.net.InetAddress;
import java.net.UnknownHostException;
import java.util.List;

/**
 * @author ZPF
 * @description
 * @since 2023/1/18 08:54
 */
@Component
@Slf4j
@RequiredArgsConstructor
public class InitProcessTask {

    private final IRegionService regionService;

    // 定时更新车辆状态
    @Scheduled(cron = "0 52 15 18 1 ?")
    public void doTask() throws UnknownHostException {
        if (TaskContant.Host.HOST_ZPF.equals(InetAddress.getLocalHost().getHostName())) {
            log.info("=========== 初始化丽水二期 系统表单和流程配置 ======== 任务开始");
            StopWatch stopWatch = new StopWatch();
            stopWatch.start();
            //1.查出丽水市下的 区县 分别去初始化 表单和流程配置数据
            List<Region> regions = regionService.list(Wrappers.lambdaQuery(Region.class)
                    .eq(Region::getDeleted,Boolean.FALSE)
                    .eq(Region::getParentCode, RegionContant.LS_REGION_CODE));

            if(CollUtil.isEmpty(regions)){
                throw new BizException("丽水地区数据为空 任务结束!");
            }

            //2.首先插入表单默认配置
            for(Region region : regions){
                log.info("当前初始化的是 【{}】",region.getName());

            }

            stopWatch.stop();
            log.info("=========== 更新车辆在线状态 ======== 任务结束 {}s",stopWatch.getTotalTimeSeconds());
        }
    }
}
